package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherKpiFillingRewardsKpi;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 业绩考核-个人填报-超工作量奖励绩效Mapper接口
 *
 * @author chc
 * @date 2024-06-12
 */
public interface SysTeacherKpiFillingRewardsKpiMapper extends BaseMapper<SysTeacherKpiFillingRewardsKpi> {
    /**
     * 查询业绩考核-个人填报-超工作量奖励绩效
     *
     * @param id 业绩考核-个人填报-超工作量奖励绩效主键
     * @return 业绩考核-个人填报-超工作量奖励绩效
     */
    public SysTeacherKpiFillingRewardsKpi selectSysTeacherKpiFillingRewardsKpiById(Long id);

    /**
     * 查询业绩考核-个人填报-超工作量奖励绩效列表
     *
     * @param sysTeacherKpiFillingRewardsKpi 业绩考核-个人填报-超工作量奖励绩效
     * @return 业绩考核-个人填报-超工作量奖励绩效集合
     */
    List<SysTeacherKpiFillingRewardsKpi> selectSysTeacherKpiFillingRewardsKpiList(SysTeacherKpiFillingRewardsKpi sysTeacherKpiFillingRewardsKpi);

    /**
     * 查根据辅导员名称、年份 月份 查询
     *
     * @param fdyName 辅导员名称
     * @return 业绩考核-个人填报-超工作量奖励绩效集合
     */
    List<SysTeacherKpiFillingRewardsKpi> selectSysTeacherKpiFillingRewardsKpiByFdyName(@Param("fdyName") String fdyName, @Param("fillingYear") String fillingYear, @Param("fillingMonth") String fillingMonth, @Param("classType") String classType);


    /**
     * 新增业绩考核-个人填报-超工作量奖励绩效
     *
     * @param sysTeacherKpiFillingRewardsKpi 业绩考核-个人填报-超工作量奖励绩效
     * @return 结果
     */
    int insertSysTeacherKpiFillingRewardsKpi(SysTeacherKpiFillingRewardsKpi sysTeacherKpiFillingRewardsKpi);

    /**
     * 修改业绩考核-个人填报-超工作量奖励绩效
     *
     * @param sysTeacherKpiFillingRewardsKpi 业绩考核-个人填报-超工作量奖励绩效
     * @return 结果
     */
    int updateSysTeacherKpiFillingRewardsKpi(SysTeacherKpiFillingRewardsKpi sysTeacherKpiFillingRewardsKpi);

    /**
     * 删除业绩考核-个人填报-超工作量奖励绩效
     *
     * @param id 业绩考核-个人填报-超工作量奖励绩效主键
     * @return 结果
     */
    int deleteSysTeacherKpiFillingRewardsKpiById(Long id);

    /**
     * 批量删除业绩考核-个人填报-超工作量奖励绩效
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherKpiFillingRewardsKpiByIds(Long[] ids);
}
